import httplib, urllib
from urlparse import urlparse
from xml.dom import minidom
from Globals import InitializeClass
from Acquisition import aq_base
from AccessControl import ClassSecurityInfo
from OFS.SimpleItem import SimpleItem
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFCore.ActionInformation import ActionInformation
from Products.CMFCore.utils import UniqueObject
from Ping import PingContainer

class TrackbackTool(UniqueObject, SimpleItem, ActionProviderBase):
    """
    Movabletype trackback tool
    """

    id = 'portal_trackback'
    meta_type = 'CMF Trackback Tool'
    security = ClassSecurityInfo()

    manage_options = ActionProviderBase.manage_options

    _actions = [ActionInformation(id='sendping',
                                  title='Send ping',
                                  action='string:$object_url/sendping_form',
                                  condition='python:folder is not object and object.Creator()==str(member)',
                                  permissions=('View',),
                                  category='object_tabs',
                                  visible=1,)
                ]

    security.declarePublic('getTrackbackFor')
    def getTrackbackFor(self, content):
        """
        Return trackback
        """
#        content = aq_base(content)
        trackback = getattr(content, 'trackback', None)
        if not trackback:
            trackback = self._createTrackbackFor(content)
        return trackback

    def _createTrackbackFor(self, content):
        """
        Create trackback
        """
        if hasattr(content, '_isPortalContent'):
            content.trackback = PingContainer()
        else:
            raise "TrackbackError", "here is not trackback ping url"
        return content.trackback

    security.declarePublic('sendPing')
    def sendPing(self, target, title, excerpt, url, blog_name):
        """
        Send trackback ping
        """
        p=urllib.urlencode({'title':title,'url':url,'excerpt':excerpt,
                            'blog_name':blog_name})
        x = urlparse(target)
        host = x[1]
        path = x[2]

        h=httplib.HTTP(host)
        h.putrequest('POST', path)
        h.putheader('Content-type', 'application/x-www-form-urlencoded')
        h.putheader("Content-length", "%d" % len(p))
        h.endheaders()
        h.send(p)

        reply, msg, hdrs = h.getreply()
        #Waaa!
        if reply==200:
            data = h.getfile().read()
            try:
                dom = minidom.parseString(data)
                error = dom.getElementsByTagName('error')[0].childNodes[0].data
            except:
                error = '1'
            return error
        else:
            return '1'

    security.declarePublic('coundPings')
    def countPings(self, object):
        """
        """
        if hasattr(object, 'trackback'):
            return len(object.trackback.objectIds())
        else:
            return 0

InitializeClass(TrackbackTool)
